//use tensor_rs::tensor::*;
//use tensor_rs::tensor::blas::*;
//extern crate openblas_src;

#[test]
fn test_mm() {

    //{
    //    let mut v1: Vec<f32> = (0..128*256).map(|x| x as f32).collect();
    //    let mut v2: Vec<f32> = (0..128*256).map(|x| x as f32).collect();
    //    let mut v3: [f32; 65536] = [0.; 65536];
    //
    //    for _i in 0..10000 {
    //        let trans = false;
    //        BlasAPI::<f32>::gemm(trans, trans, 256, 256, 128, 1., &v1, 256, &v2, 128, 1., &mut v3, 256);
    //    //println!("{:?}", v3);        
    //    }
    //}
    


    //{
    //    let v1 = Tensor::ones(&[256, 128]);
    //    let v2 = Tensor::ones(&[128, 256]);
    //
    //    for _i in 0..10000 {
    //        v1.mm(&v2);
    //    }
    //}


}
